from setuptools import setup

setup(name='Drive_share_library',
      version='0.1',
      description='route and cost calculation library',
      packages=['Drive_share_library'],
      author_email='palnatisaikumarreddy150@gmail.com',
      zip_safe=False)